@@ -67,20 +67,7 @@ class KTEXTEDITOR_EXPORT EditorPrivate final : public KTextEditor::Editor
 
     friend class KTextEditor::Editor;
 
-    // unit testing support
 public:
-    /**
-     * Calling this function internally sets a flag such that unitTestMode()
-     * returns \p true.
-     */
-    static void enableUnitTestMode();
-
-    /**
-     * Returns \p true, if the unit test mode was enabled through a call of
-     * enableUnitTestMode(), otherwise \p false.
-     */
-    static bool unitTestMode();
-
     // for setDefaultEncoding
     friend class KateDocumentConfig;
 
